import { useState } from 'react';

function isFunction(value) {
  return typeof value === "function";
}
function resolveSetterProp(setter, oldValue) {
  if (isFunction(setter)) {
    return setter(oldValue);
  }
  return setter;
}
const useStatus = (startingStatus) => {
  const [state, setState] = useState(startingStatus);
  function stateFn(value) {
    if (arguments.length === 0) {
      return state;
    } else {
      let newValue = resolveSetterProp(value, state);
      setState(newValue);
    }
  }
  stateFn.value = state;
  const stateFnProxy = new Proxy(stateFn, {
    set: function(target, prop, value) {
      if (prop === "value") {
        setState(value);
        target[prop] = value;
        return true;
      }
      return Reflect.set(...arguments);
    }
  });
  return stateFnProxy;
};

export { useStatus };
